django-browserid
================

|TravisCI|_

.. |TravisCI| image:: https://secure.travis-ci.org/mozilla/django-browserid.png?branch=master
.. _TravisCI: https://secure.travis-ci.org/mozilla/django-browserid

django-browserid is a library that integrates BrowserID_ authentication into
Django_.

Supported versions range from Python 2.6 onwards and Django >=1.4.8. For
more details, check this project's `tox test suite`_ or TravisCI_.

.. _Django: http://www.djangoproject.com/
.. _BrowserID: https://login.persona.org/
.. _tox test suite: https://github.com/mozilla/django-browserid/blob/master/tox.ini


Documentation
-------------

http://django-browserid.rtfd.org


Need Help?
----------

First, check out the `troubleshooting`_ section of the documentation, which
covers solutions to several common problems.

If that doesn't help, questions can be sent to the #webdev channel on
irc.mozilla.org, or by email to the `current maintainer`_.

.. _troubleshooting: http://django-browserid.readthedocs.org/en/latest/details/troubleshooting.html
.. _current maintainer: mailto:mkelly@mozilla.org


License
-------

This software is licensed under the `Mozilla Public License v. 2.0`_. For more
information, read the file ``LICENSE``.

.. _Mozilla Public License v. 2.0: http://mozilla.org/MPL/2.0/
